==> openshift-serverless-logic-1.26.0-src.zip: openshift-serverless-logic-1.26.0.GA-src/org.kie.kogito-kogito-apps-1.30.0.Final/ui-packages/packages/custom-dashboard-list/src/envelope/CustomDashboardListEnvelopeViewDriver.ts <==
/*
 * Copyright 2022 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { MessageBusClientApi } from '@kogito-tooling/envelope-bus/dist/api';
import {
  CustomDashboardFilter,
  CustomDashboardListChannelApi,
  CustomDashboardListDriver,
  CustomDashboardInfo
} from '../api';

/**
 * Implementation of CustomDashboardListDriver that delegates calls to the channel Api
 */
export default class CustomDashboardListEnvelopeViewDriver
  implements CustomDashboardListDriver {
  constructor(
    private readonly channelApi: MessageBusClientApi<
      CustomDashboardListChannelApi
    >
  ) {}

  getCustomDashboardFilter(): Promise<CustomDashboardFilter> {
    return this.channelApi.requests.customDashboardList__getFilter();
  }

  applyFilter(customDashboardFilter: CustomDashboardFilter): Promise<void> {
    return this.channelApi.requests.customDashboardList__applyFilter(
      customDashboardFilter
    );
  }

  getCustomDashboardsQuery(): Promise<CustomDashboardInfo[]> {
    return this.channelApi.requests.customDashboardList__getCustomDashboardQuery();
  }

  openDashboard(customDashboardInfo: CustomDashboardInfo): Promise<void> {
    return this.channelApi.requests.customDashboardList__openDashboard(
      customDashboardInfo
    );
  }
}

==> openshift-serverless-logic-1.28.0-src.zip: openshift-serverless-logic-1.28.0.GA-src/org.kie.kogito-kogito-apps-1.35.0.Final/ui-packages/packages/custom-dashboard-list/src/envelope/CustomDashboardListEnvelopeViewDriver.ts <==
/*
 * Copyright 2022 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { MessageBusClientApi } from '@kogito-tooling/envelope-bus/dist/api';
import {
  CustomDashboardFilter,
  CustomDashboardListChannelApi,
  CustomDashboardListDriver,
  CustomDashboardInfo
} from '../api';

/**
 * Implementation of CustomDashboardListDriver that delegates calls to the channel Api
 */
export default class CustomDashboardListEnvelopeViewDriver
  implements CustomDashboardListDriver
{
  constructor(
    private readonly channelApi: MessageBusClientApi<CustomDashboardListChannelApi>
  ) {}

  getCustomDashboardFilter(): Promise<CustomDashboardFilter> {
    return this.channelApi.requests.customDashboardList__getFilter();
  }

  applyFilter(customDashboardFilter: CustomDashboardFilter): Promise<void> {
    return this.channelApi.requests.customDashboardList__applyFilter(
      customDashboardFilter
    );
  }

  getCustomDashboardsQuery(): Promise<CustomDashboardInfo[]> {
    return this.channelApi.requests.customDashboardList__getCustomDashboardQuery();
  }

  openDashboard(customDashboardInfo: CustomDashboardInfo): Promise<void> {
    return this.channelApi.requests.customDashboardList__openDashboard(
      customDashboardInfo
    );
  }
}
